==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Forrige side");
define("_NEXT","Nste side");
define("_YOURNAME","Dit navn");
define("_SORTASC","Sorter stigende");
define("_SORTDESC","Sorter faldende");
define("_CANCEL","Fortryd");
define("_YES","Ja");
define("_NO","Nej");
define("_SCORE","Hits:");
define("_REPLYMAIN","Send kommentar");
define("_ALLOWEDHTML","Tilladte HTML-koder:");
define("_POSTANON","Anonymt indlg");
define("_WRITEREVIEW","Skriv en anmeldelse");
define("_WRITEREVIEWFOR","Skriv en anmeldelse til");
define("_ENTERINFO","Vr venlig at udfylde felterne i henhold til instruktionerne");
define("_PRODUCTTITLE","Overskrift p anmeldelse");
define("_NAMEPRODUCT","Navn p det anmeldte.");
define("_REVIEW","Tekst");
define("_CHECKREVIEW","Din anmeldelse som den vil se ud. Vr venlig at kontrollere granmatik og tegnstning. Vr venlig at skrive mindst 100 ord, tak! Du er velkommen til at anvende HTML-koder, hvis du kan bruge dem.");
define("_FULLNAMEREQ","Bde for- og efternavn. Skal udfyldes");
define("_REMAIL","Din e-mailadresse");
define("_REMAILREQ","Din e-mailadresse. Skal udfyldes");
define("_SELECTSCORE","Angiv en score:");
define("_RELATEDLINK","Relateret link");
define("_PRODUCTSITE","Det anmeldtes officielle website. (Hvis der er nogen.) Kontroller at internetadressen starter med \"http://\"");
define("_LINKTITLE","Titel p link");
define("_LINKTITLEREQ","Skal udfyldels hvis du har et relateret link, ellers ikke.");
define("_RIMAGEFILE","Filnavn p billede");
define("_RIMAGEFILEREQ","Filnavn p billede,- placeret i mappen: images/reviews/. Ikke ndvendigt. Tilfjes eventuelt af administrator.");
define("_CHECKINFO","Vr venlig at kontrollere, at alle oplysninger er 100% korrekte, og at du har gramatik og tegnstning i orden. For eksempel bedes du om ikke at skrive din tekst med kun STORE BOGSTAVER, da de vil bliver afvist af vores systemer.");
define("_INVALIDTITLE","Fejl i overskriften... Skal udfyldes");
define("_INVALIDSCORE","Fejl i score... Skal vre mellem 1 og 10");
define("_INVALIDTEXT","Fejl i anmeldelsesteksten... Skal udfyldes");
define("_INVALIDHITS","Hits skal vre et positivt tal");
define("_CHECKNAME","Du skal skrive bde dit navn og din e-mailadresse");
define("_INVALIDEMAIL","Fejl i e-mailadresse. (f.eks.: ditnavn@hotmail.com)");
define("_INVALIDLINK","Du skal skrive BDE en titel p linket og et relateret link eller lade begge felter vre tomme.");
define("_ADDED","Tilfjet:");
define("_REVIEWER","Anmelder:");
define("_REVIEWID","ID p anmeldelse");
define("_HITS","Hits");
define("_LOOKSRIGHT","Ser dette rigtigt ud?");
define("_RMODIFIED","ndret");
define("_RADDED","tilfjet");
define("_ADMINLOGGED","Logget ind som administrator... anmeldelsen vil kunne ses med det samme.");
define("_RTHANKS","Tak for indsendelsen af denne anmeldelse!");
define("_MODIFICATION","ndring");
define("_ISAVAILABLE","Den er nu klar i vores anmeldelsesdatabase.");
define("_EDITORWILLLOOK","Vores team vil gennemlse din anmeldelse. Den skulle vre klart snarest.!");
define("_RBACK","Tilbage til oversigten over anmeldelser");
define("_RWELCOME","Velkommen til sektionen for anmeldelser");
define("_10MOSTPOP","De 10 mest populre anmeldelser");
define("_10MOSTREC","De 10 nyeste anmeldelser");
define("_THEREARE","Der er");
define("_REVIEWSINDB","anmeldelser i vores database");
define("_REVIEWS","Administration af anmeldelser");
define("_REVIEWSLETTER","Anmeldelser efter bogstavet");
define("_NOREVIEWS","Der er ingen anmeldelser efter bogstavet");
define("_TOTALREVIEWS","Antal anmeldelser fundet.");
define("_RETURN2MAIN","Tilbage til hovedsektionen");
define("_REVIEWCOMMENT","Kommentarer til denne anmeldelse:");
define("_YOURNICK","Dit brugernavn:");
define("_RCREATEACCOUNT","<a href=modules.php?name=Your_Account>Opret</a> dig som bruger");
define("_YOURCOMMENT","Din kommentar:");
define("_MYSCORE","Min score:");
define("_REVIEWMOD","ndring af anmeldelse");
define("_RDATE","Dato:");
define("_RTITLE","Overskrift:");
define("_RTEXT","Tekst:");
define("_REVEMAIL","E-mail:");
define("_RLINK","Link:");
define("_RLINKTITLE","Titel p link:");
define("_COVERIMAGE","Forsidebillede:");
define("_PREMODS","Gennemse ndringer");
define("_PAGE","Side");
define("_PAGEBREAK","Hvis du har flere sider kan du skrive <b>&lt;!--pagebreak--&gt;</b> hvor du vil have et sideskift i din tekst.");
define("_PREVIEW","Gennemse");
define("_LANGUAGE","Language");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Forrige side");
define("_NEXT","Nste side");
define("_YOURNAME","Dit navn");
define("_SORTASC","Sorter stigende");
define("_SORTDESC","Sorter faldende");
define("_CANCEL","Fortryd");
define("_YES","Ja");
define("_NO","Nej");
define("_SCORE","Hits:");
define("_REPLYMAIN","Send kommentar");
define("_ALLOWEDHTML","Tilladte HTML-koder:");
define("_POSTANON","Anonymt indlg");
define("_WRITEREVIEW","Skriv en anmeldelse");
define("_WRITEREVIEWFOR","Skriv en anmeldelse til");
define("_ENTERINFO","Vr venlig at udfylde felterne i henhold til instruktionerne");
define("_PRODUCTTITLE","Overskrift p anmeldelse");
define("_NAMEPRODUCT","Navn p det anmeldte.");
define("_REVIEW","Tekst");
define("_CHECKREVIEW","Din anmeldelse som den vil se ud. Vr venlig at kontrollere granmatik og tegnstning. Vr venlig at skrive mindst 100 ord, tak! Du er velkommen til at anvende HTML-koder, hvis du kan bruge dem.");
define("_FULLNAMEREQ","Bde for- og efternavn. Skal udfyldes");
define("_REMAIL","Din e-mailadresse");
define("_REMAILREQ","Din e-mailadresse. Skal udfyldes");
define("_SELECTSCORE","Angiv en score:");
define("_RELATEDLINK","Relateret link");
define("_PRODUCTSITE","Det anmeldtes officielle website. (Hvis der er nogen.) Kontroller at internetadressen starter med \"http://\"");
define("_LINKTITLE","Titel p link");
define("_LINKTITLEREQ","Skal udfyldels hvis du har et relateret link, ellers ikke.");
define("_RIMAGEFILE","Filnavn p billede");
define("_RIMAGEFILEREQ","Filnavn p billede,- placeret i mappen: images/reviews/. Ikke ndvendigt. Tilfjes eventuelt af administrator.");
define("_CHECKINFO","Vr venlig at kontrollere, at alle oplysninger er 100% korrekte, og at du har gramatik og tegnstning i orden. For eksempel bedes du om ikke at skrive din tekst med kun STORE BOGSTAVER, da de vil bliver afvist af vores systemer.");
define("_INVALIDTITLE","Fejl i overskriften... Skal udfyldes");
define("_INVALIDSCORE","Fejl i score... Skal vre mellem 1 og 10");
define("_INVALIDTEXT","Fejl i anmeldelsesteksten... Skal udfyldes");
define("_INVALIDHITS","Hits skal vre et positivt tal");
define("_CHECKNAME","Du skal skrive bde dit navn og din e-mailadresse");
define("_INVALIDEMAIL","Fejl i e-mailadresse. (f.eks.: ditnavn@hotmail.com)");
define("_INVALIDLINK","Du skal skrive BDE en titel p linket og et relateret link eller lade begge felter vre tomme.");
define("_ADDED","Tilfjet:");
define("_REVIEWER","Anmelder:");
define("_REVIEWID","ID p anmeldelse");
define("_HITS","Hits");
define("_LOOKSRIGHT","Ser dette rigtigt ud?");
define("_RMODIFIED","ndret");
define("_RADDED","tilfjet");
define("_ADMINLOGGED","Logget ind som administrator... anmeldelsen vil kunne ses med det samme.");
define("_RTHANKS","Tak for indsendelsen af denne anmeldelse!");
define("_MODIFICATION","ndring");
define("_ISAVAILABLE","Den er nu klar i vores anmeldelsesdatabase.");
define("_EDITORWILLLOOK","Vores team vil gennemlse din anmeldelse. Den skulle vre klart snarest.!");
define("_RBACK","Tilbage til oversigten over anmeldelser");
define("_RWELCOME","Velkommen til sektionen for anmeldelser");
define("_10MOSTPOP","De 10 mest populre anmeldelser");
define("_10MOSTREC","De 10 nyeste anmeldelser");
define("_THEREARE","Der er");
define("_REVIEWSINDB","anmeldelser i vores database");
define("_REVIEWS","Administration af anmeldelser");
define("_REVIEWSLETTER","Anmeldelser efter bogstavet");
define("_NOREVIEWS","Der er ingen anmeldelser efter bogstavet");
define("_TOTALREVIEWS","Antal anmeldelser fundet.");
define("_RETURN2MAIN","Tilbage til hovedsektionen");
define("_REVIEWCOMMENT","Kommentarer til denne anmeldelse:");
define("_YOURNICK","Dit brugernavn:");
define("_RCREATEACCOUNT","<a href=modules.php?name=Your_Account>Opret</a> dig som bruger");
define("_YOURCOMMENT","Din kommentar:");
define("_MYSCORE","Min score:");
define("_REVIEWMOD","ndring af anmeldelse");
define("_RDATE","Dato:");
define("_RTITLE","Overskrift:");
define("_RTEXT","Tekst:");
define("_REVEMAIL","E-mail:");
define("_RLINK","Link:");
define("_RLINKTITLE","Titel p link:");
define("_COVERIMAGE","Forsidebillede:");
define("_PREMODS","Gennemse ndringer");
define("_PAGE","Side");
define("_PAGEBREAK","Hvis du har flere sider kan du skrive <b>&lt;!--pagebreak--&gt;</b> hvor du vil have et sideskift i din tekst.");
define("_PREVIEW","Gennemse");
define("_LANGUAGE","Language");

?>
